api.reputation.v1.calculated package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.calculated package

## Submodules

## api.reputation.v1.calculated.calculated_domain module

Autogenerated API

`api.reputation.v1.calculated.calculated_domain.` `calculate_reputation_for_domain`(fqdn: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up the calculated reputation value for the given Domain (INTERNAL)

  Return type: | `dict`
  Parameters: | fqdn (str) – Domain to look up
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 437, “limit”: 789, “responseCode”: 200, “count”: 433, “data”: [{“override”: true, “reason”: “Institution college everybody month worry character debate commercial.”, “value”: 48}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Total movement whole land fear seven campaign.”, “messageTemplate”: “Ten I type billion.”, “field”: “Personal hour yard defense analysis.”, “parameter”: {}, “timestamp”: 785964758}], “currentPage”: 487, “size”: 263}

`api.reputation.v1.calculated.calculated_domain.` `calculate_reputation_for_i_p`(ip: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up the calculated reputation value for the given IP (INTERNAL)

  Return type: | `dict`
  Parameters: | ip (str) – IP address to look up
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 436, “limit”: 280, “responseCode”: 200, “count”: 829, “data”: [{“override”: true, “reason”: “Bit dog door choose no force central church.”, “value”: 533}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Detail TV final to easy education talk party.”, “messageTemplate”: “Culture action sport official like structure him.”, “field”: “Conference deep tree painting during appear authority mission.”, “parameter”: {}, “timestamp”: 1366085168}], “currentPage”: 795, “size”: 44}

`api.reputation.v1.calculated.calculated_domain.` `find_address_reputation`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, minimumValue: int = None, sourceID: list = None, fromAddress: str = None, afterAddress: str = None, addresses: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search for calculated IP reputation values (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – minimumValue (int) – sourceID (list) – fromAddress (str) – afterAddress (str) – addresses (list) – List of IP addresses includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 206, “limit”: 919, “responseCode”: 200, “count”: 979, “data”: [{“override”: true, “reason”: “Audience none actually through similar he improve office.”, “value”: 793}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Member fast nearly modern dark site.”, “messageTemplate”: “Analysis policy month rest reason deep.”, “field”: “Raise service foot.”, “parameter”: {}, “timestamp”: 814841100}], “currentPage”: 245, “size”: 682}

`api.reputation.v1.calculated.calculated_domain.` `find_domain_reputation`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, minimumValue: int = None, sourceID: list = None, fromDomainName: str = None, afterDomainName: str = None, domainNames: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search for calculated domain reputation values (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – minimumValue (int) – sourceID (list) – fromDomainName (str) – afterDomainName (str) – domainNames (list) – Full Qualified Domain Names includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 196, “limit”: 308, “responseCode”: 200, “count”: 679, “data”: [{“override”: false, “reason”: “Model science as professor prepare daughter send bad.”, “value”: 938}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “What speak sound least test near knowledge.”, “messageTemplate”: “Help according cultural song.”, “field”: “Hold green yet standard.”, “parameter”: {}, “timestamp”: 1495982312}], “currentPage”: 183, “size”: 812}

`api.reputation.v1.calculated.calculated_domain.` `list_address_reputation`(fromAddress: str = None, afterAddress: str = None, sourceID: int = None, minimumValue: int = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List up calculated IP reputation values (INTERNAL)

  Return type: | `dict`
  Parameters: | fromAddress (str) – List observed domains after this domain, including (sorted by reverse domain) afterAddress (str) – List observed domains after this domain, excluding (sorted by reverse domain) sourceID (int) – Limit to domains observed in this source minimumValue (int) – Limit to domains which have a reputation score at lease this large limit (int) – Limit output offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 621, “limit”: 30, “responseCode”: 200, “count”: 175, “data”: [{“override”: false, “reason”: “Lawyer share positive time law southern.”, “value”: 347}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ever fear threat government place wait most.”, “messageTemplate”: “Drug entire spend reality travel line.”, “field”: “Almost kid chair Mrs lawyer while close.”, “parameter”: {}, “timestamp”: 1300657304}], “currentPage”: 903, “size”: 692}

`api.reputation.v1.calculated.calculated_domain.` `list_domain_reputation`(fromDomain: str = None, afterDomain: str = None, sourceID: int = None, minimumValue: int = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List up calculated domain reputation values (INTERNAL)

  Return type: | `dict`
  Parameters: | fromDomain (str) – List observed domains after this domain, including (sorted by reverse domain) afterDomain (str) – List observed domains after this domain, excluding (sorted by reverse domain) sourceID (int) – Limit to domains observed in this source minimumValue (int) – Limit to domains which have a reputation score at lease this large limit (int) – Limit output offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 383, “limit”: 393, “responseCode”: 200, “count”: 894, “data”: [{“override”: false, “reason”: “Believe explain table man strong offer.”, “value”: 796}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Culture yeah teach behind pick million.”, “messageTemplate”: “Traditional attention something money on high usually.”, “field”: “Expect fire provide training.”, “parameter”: {}, “timestamp”: 521124238}], “currentPage”: 432, “size”: 821}

## Module contents